export class Cell {
    /**
     * @param serializedBoc  {string | Uint8Array} hex or bytearray
     * @return {Cell[]} root cells
     */
    static fromBoc(serializedBoc: string | Uint8Array): Cell[];
    /**
     * @param serializedBoc  {string | Uint8Array} hex or bytearray
     * @return {Cell} root cell
     */
    static oneFromBoc(serializedBoc: string | Uint8Array): Cell;
    bits: BitString;
    refs: any[];
    isExotic: boolean;
    /**
     * Write another cell to this cell
     * @param anotherCell  {Cell}
     */
    writeCell(anotherCell: Cell): void;
    /**
     * @return {number}
     */
    getMaxLevel(): number;
    /**
     * @return {number}
     */
    isExplicitlyStoredHashes(): number;
    /**
     * @return {number}
     */
    getMaxDepth(): number;
    /**
     * @private
     * @return {Uint8Array}
     */
    private getMaxDepthAsArray;
    /**
     * @return {Uint8Array}
     */
    getRefsDescriptor(): Uint8Array;
    /**
     * @return {Uint8Array}
     */
    getBitsDescriptor(): Uint8Array;
    /**
     * @return {Uint8Array}
     */
    getDataWithDescriptors(): Uint8Array;
    /**
     * @return {Promise<Uint8Array>}
     */
    getRepr(): Promise<Uint8Array>;
    /**
     * @return {Promise<Uint8Array>}
     */
    hash(): Promise<Uint8Array>;
    /**
     * @returns {Slice}
     */
    beginParse(): Slice;
    /**
     * Recursively prints cell's content like Fift
     * @return  {string}
     */
    print(indent: any): string;
    /**
     * create boc bytearray
     * @param has_idx? {boolean}
     * @param hash_crc32?  {boolean}
     * @param has_cache_bits?  {boolean}
     * @param flags? {number}
     * @return {Promise<Uint8Array>}
     */
    toBoc(has_idx?: boolean, hash_crc32?: boolean, has_cache_bits?: boolean, flags?: number): Promise<Uint8Array>;
    /**
     * @private
     * @param cellsIndex
     * @param refSize
     * @return {Promise<Uint8Array>}
     */
    private serializeForBoc;
    /**
     * @private
     * @param cellsIndex
     * @param refSize
     * @return {Promise<number>}
     */
    private bocSerializationSize;
    /**
     * @private
     * @return {[[], {}]} topologicalOrderArray and indexHashmap
     */
    private treeWalk;
}
import { BitString } from "./BitString";
import { Slice } from "./Slice";
//# sourceMappingURL=Cell.d.ts.map