export default Dns;
declare class Dns {
    /**
     * @param provider  {HttpProvider}
     */
    constructor(provider: HttpProvider);
    provider: HttpProvider;
    /**
     * @returns {Promise<Address>}
     */
    getRootDnsAddress(): Promise<Address>;
    /**
     * @param domain    {string} e.g "sub.alice.ton"
     * @param category  {string | undefined} category of requested DNS record, null for all categories
     * @param oneStep {boolean | undefined}  non-recursive
     * @returns {Promise<Cell | Address | AdnlAddress | StorageBagId | null>}
     */
    resolve(domain: string, category: string | undefined, oneStep: boolean | undefined): Promise<Cell | Address | AdnlAddress | StorageBagId | null>;
    /**
     * @param domain    {string} e.g "sub.alice.ton"
     * @returns {Promise<Address | null>}
     */
    getWalletAddress(domain: string): Promise<Address | null>;
    /**
     * @param domain    {string} e.g "sub.alice.ton"
     * @returns {Promise<AdnlAddress | StorageBagId | null>}
     */
    getSiteAddress(domain: string): Promise<AdnlAddress | StorageBagId | null>;
}
declare namespace Dns {
    export { dnsResolve as resolve };
    export { createSmartContractAddressRecord };
    export { createAdnlAddressRecord };
    export { createStorageBagIdRecord };
    export { createNextResolverRecord };
    export { parseNextResolverRecord };
    export { parseAdnlAddressRecord };
    export { parseStorageBagIdRecord };
    export { parseSiteRecord };
    export { parseSmartContractAddressRecord };
    export { DNS_CATEGORY_NEXT_RESOLVER };
    export { DNS_CATEGORY_WALLET };
    export { DNS_CATEGORY_SITE };
    export { DNS_CATEGORY_STORAGE };
}
import { Address } from "../../utils";
import { Cell } from "../../boc";
import { dnsResolve } from "./DnsUtils";
import { createSmartContractAddressRecord } from "./DnsUtils";
import { createAdnlAddressRecord } from "./DnsUtils";
import { createStorageBagIdRecord } from "./DnsUtils";
import { createNextResolverRecord } from "./DnsUtils";
import { parseNextResolverRecord } from "./DnsUtils";
import { parseAdnlAddressRecord } from "./DnsUtils";
import { parseStorageBagIdRecord } from "./DnsUtils";
import { parseSiteRecord } from "./DnsUtils";
import { parseSmartContractAddressRecord } from "./DnsUtils";
import { DNS_CATEGORY_NEXT_RESOLVER } from "./DnsUtils";
import { DNS_CATEGORY_WALLET } from "./DnsUtils";
import { DNS_CATEGORY_SITE } from "./DnsUtils";
import { DNS_CATEGORY_STORAGE } from "./DnsUtils";
//# sourceMappingURL=Dns.d.ts.map