export class DnsItem extends Contract {
    /**
     * @param provider
     * @param options   {{index: BN, collectionAddress: Address, address?: Address | string, code?: Cell}}
     */
    constructor(provider: any, options: {
        index: BN;
        collectionAddress: Address;
        address?: Address | string;
        code?: Cell;
    });
    /**
     * @return {Promise<{isInitialized: boolean, index: BN, collectionAddress: Address|null, ownerAddress: Address|null, contentCell: Cell}>}
     */
    getData(): Promise<{
        isInitialized: boolean;
        index: BN;
        collectionAddress: Address | null;
        ownerAddress: Address | null;
        contentCell: Cell;
    }>;
    /**
     * @param params    {{queryId?: number, newOwnerAddress: Address, forwardAmount?: BN, forwardPayload?: Uint8Array, responseAddress: Address}}
     */
    createTransferBody(params: {
        queryId?: number;
        newOwnerAddress: Address;
        forwardAmount?: BN;
        forwardPayload?: Uint8Array;
        responseAddress: Address;
    }): Promise<Cell>;
    /**
     * params   {{queryId?: number}}
     * @return {Cell}
     */
    createGetStaticDataBody(params: any): Cell;
    /**
     * @return {Promise<string>}
     */
    getDomain(): Promise<string>;
    /**
     * @return {Promise<{maxBidAddress: Address|null, maxBidAmount: BN, auctionEndTime: number}>}
     */
    getAuctionInfo(): Promise<{
        maxBidAddress: Address | null;
        maxBidAmount: BN;
        auctionEndTime: number;
    }>;
    /**
     * @return {Promise<number>}
     */
    getLastFillUpTime(): Promise<number>;
    /**
     * @param domain    {string} e.g "sub.alice.ton"
     * @param category?  {string} category of requested DNS record, null for all categories
     * @param oneStep? {boolean} non-recursive
     * @returns {Promise<Cell | Address | AdnlAddress | StorageBagId | null>}
     */
    resolve(domain: string, category: any, oneStep: any): Promise<Cell | Address | AdnlAddress | StorageBagId | null>;
}
export namespace DnsItem {
    /**
     * params   {{category: string, value: Cell|null, queryId?: number}}
     * @return {Cell}
     */
    function createChangeContentEntryBody(params: any): Cell;
}
import { Contract } from "../../contract/index.js";
import { Address } from "../../utils";
import { Cell } from "../../boc";
//# sourceMappingURL=DnsItem.d.ts.map