export const DNS_CATEGORY_NEXT_RESOLVER: "dns_next_resolver";
export const DNS_CATEGORY_SITE: "site";
export const DNS_CATEGORY_WALLET: "wallet";
export const DNS_CATEGORY_STORAGE: "storage";
/**
 * @param category  {string | undefined}
 * @return  {BN}
 */
export function categoryToBN(category: string | undefined): BN;
/**
 * Verify and convert domain
 * @param domain    {string}
 * @return {Uint8Array}
 */
export function domainToBytes(domain: string): Uint8Array;
/**
 * @param smartContractAddress   {Address}
 * @return {Cell}
 */
export function createSmartContractAddressRecord(smartContractAddress: Address): Cell;
/**
 * @param adnlAddress   {AdnlAddress}
 * @return {Cell}
 */
export function createAdnlAddressRecord(adnlAddress: AdnlAddress): Cell;
/**
 * @param smartContractAddress   {Address}
 * @return {Cell}
 */
export function createNextResolverRecord(smartContractAddress: Address): Cell;
/**
 * @param cell  {Cell}
 * @return {Address|null}
 */
export function parseSmartContractAddressRecord(cell: Cell): Address | null;
/**
 * @param cell  {Cell}
 * @return {AdnlAddress}
 */
export function parseAdnlAddressRecord(cell: Cell): AdnlAddress;
/**
 * @param cell  {Cell}
 * @return {StorageBagId}
 */
export function parseStorageBagIdRecord(cell: Cell): StorageBagId;
/**
 * @param cell  {Cell}
 * @return {AdnlAddress|StorageBagId|null}
 */
export function parseSiteRecord(cell: Cell): AdnlAddress | StorageBagId | null;
/**
 * @param cell  {Cell}
 * @return {Address|null}
 */
export function parseNextResolverRecord(cell: Cell): Address | null;
/**
 * @param storageBagId   {StorageBagId}
 * @return {Cell}
 */
export function createStorageBagIdRecord(storageBagId: StorageBagId): Cell;
/**
 * @param provider  {HttpProvider}
 * @param rootDnsAddress {string} address of root DNS smart contract
 * @param domain    {string} e.g "sub.alice.ton"
 * @param category  {string | undefined} category of requested DNS record
 * @param oneStep {boolean | undefined} non-recursive
 * @returns {Promise<Cell | Address | AdnlAddress | StorageBagId | null>}
 */
export function dnsResolve(provider: HttpProvider, rootDnsAddress: string, domain: string, category: string | undefined, oneStep: boolean | undefined): Promise<Cell | Address | AdnlAddress | StorageBagId | null>;
import { Cell } from "../../boc";
import { AdnlAddress } from "../../utils";
import { StorageBagId } from "../../utils";
//# sourceMappingURL=DnsUtils.d.ts.map