export class Contract {
    /**
     * @param code  {Cell}
     * @param data  {Cell}
     * @param library {null}
     * @param splitDepth {null}
     * @param ticktock  {null}
     * @return {Cell}
     */
    static createStateInit(code: Cell, data: Cell, library?: null, splitDepth?: null, ticktock?: null): Cell;
    /**
     * @param dest  {Address | string}
     * @param gramValue  {number | BN}
     * @param ihrDisabled  {boolean}
     * @param bounce  {null | boolean}
     * @param bounced {boolean}
     * @param src  {Address | string}
     * @param currencyCollection  {null}
     * @param ihrFees  {number | BN}
     * @param fwdFees  {number | BN}
     * @param createdLt  {number | BN}
     * @param createdAt  {number | BN}
     * @return {Cell}
     */
    static createInternalMessageHeader(dest: Address | string, gramValue?: number | BN, ihrDisabled?: boolean, bounce?: null | boolean, bounced?: boolean, src?: Address | string, currencyCollection?: null, ihrFees?: number | BN, fwdFees?: number | BN, createdLt?: number | BN, createdAt?: number | BN): Cell;
    /**
     * @param dest  {Address | string}
     * @param src  {Address | string}
     * @param importFee  {number | BN}
     * @return {Cell}
     */
    static createExternalMessageHeader(dest: Address | string, src?: Address | string, importFee?: number | BN): Cell;
    /**
     * @param address {Address | string}
     * @param amount {BN} in nanotons
     * @param payload   {string | Uint8Array | Cell}
     * @param stateInit? {Cell}
     * @return {Cell}
     */
    static createOutMsg(address: Address | string, amount: BN, payload: string | Uint8Array | Cell, stateInit?: any): Cell;
    /**
     * Create CommonMsgInfo contains header, stateInit, body
     * @param header {Cell}
     * @param stateInit?  {Cell}
     * @param body?  {Cell}
     * @return {Cell}
     */
    static createCommonMsgInfo(header: Cell, stateInit?: any, body?: any): Cell;
    static createMethod(provider: any, queryPromise: any): {
        getQuery: () => Promise<any>;
        send: () => Promise<any>;
        estimateFee: () => Promise<any>;
    };
    /**
     * @param provider    {HttpProvider}
     * @param options    {{code?: Cell, address?: Address | string, wc?: number}}
     */
    constructor(provider: HttpProvider, options: {
        code?: Cell;
        address?: Address | string;
        wc?: number;
    });
    provider: HttpProvider;
    options: {
        code?: Cell;
        address?: Address | string;
        wc?: number;
    };
    address: Address;
    methods: {};
    /**
     * @return {Promise<Address>}
     */
    getAddress(): Promise<Address>;
    /**
     * @private
     * @return {Cell} cell contains contact code
     */
    private createCodeCell;
    /**
     * Method to override
     * @protected
     * @return {Cell} cell contains contract data
     */
    protected createDataCell(): Cell;
    /**
     * @protected
     * @return {Promise<{stateInit: Cell, address: Address, code: Cell, data: Cell}>}
     */
    protected createStateInit(): Promise<{
        stateInit: Cell;
        address: Address;
        code: Cell;
        data: Cell;
    }>;
}
import { Cell } from "../boc";
import { Address } from "../utils";
//# sourceMappingURL=index.d.ts.map