declare namespace _default {
    export { LockupWalletV1 };
    export const all: {
        'lockup-0.1': {
            new (provider: HttpProvider, options: {
                publicKey?: Uint8Array;
                address?: string | Address;
                wc?: number;
                config: any;
            }): LockupWalletV1;
            createStateInit(code: Cell, data: Cell, library?: null, splitDepth?: null, ticktock?: null): Cell;
            createInternalMessageHeader(dest: string | Address, gramValue?: any, ihrDisabled?: boolean, bounce?: boolean, bounced?: boolean, src?: string | Address, currencyCollection?: null, ihrFees?: any, fwdFees?: any, createdLt?: any, createdAt?: any): Cell;
            createExternalMessageHeader(dest: string | Address, src?: string | Address, importFee?: any): Cell;
            createOutMsg(address: string | Address, amount: BN, payload: string | Uint8Array | Cell, stateInit?: any): Cell;
            createCommonMsgInfo(header: Cell, stateInit?: any, body?: any): Cell;
            createMethod(provider: any, queryPromise: any): {
                getQuery: () => Promise<any>;
                send: () => Promise<any>;
                estimateFee: () => Promise<any>;
            };
        };
    };
    export const list: {
        new (provider: HttpProvider, options: {
            publicKey?: Uint8Array;
            address?: string | Address;
            wc?: number;
            config: any;
        }): LockupWalletV1;
        createStateInit(code: Cell, data: Cell, library?: null, splitDepth?: null, ticktock?: null): Cell;
        createInternalMessageHeader(dest: string | Address, gramValue?: any, ihrDisabled?: boolean, bounce?: boolean, bounced?: boolean, src?: string | Address, currencyCollection?: null, ihrFees?: any, fwdFees?: any, createdLt?: any, createdAt?: any): Cell;
        createExternalMessageHeader(dest: string | Address, src?: string | Address, importFee?: any): Cell;
        createOutMsg(address: string | Address, amount: BN, payload: string | Uint8Array | Cell, stateInit?: any): Cell;
        createCommonMsgInfo(header: Cell, stateInit?: any, body?: any): Cell;
        createMethod(provider: any, queryPromise: any): {
            getQuery: () => Promise<any>;
            send: () => Promise<any>;
            estimateFee: () => Promise<any>;
        };
    }[];
}
export default _default;
declare class LockupWalletV1 extends WalletContract {
    /**
     * @param provider    {HttpProvider}
     * @param options {{publicKey?: Uint8Array, address?: Address | string, wc?: number, config: any}}
     *
     * Config json is {config}
     */
    constructor(provider: HttpProvider, options: {
        publicKey?: Uint8Array;
        address?: Address | string;
        wc?: number;
        config: any;
    });
    getName(): string;
    /**
     * @override
     * @private
     * @param   seqno?   {number}
     * @param   withoutOp? {boolean}
     * @return {Cell}
     */
    private override createSigningMessage;
    /**
     * @return {Promise<number>}
     */
    getWalletId(): Promise<number>;
    /**
     * @return {Promise<BN>}
     */
    getPublicKey(): Promise<BN>;
    /**
     * @return {Promise<BN>} Amount of nanotoncoins that can be spent immediately.
     */
    getLiquidBalance(): Promise<BN>;
    /**
     * @return {Promise<BN>} Amount of nanotoncoins that can be spent after the timelock OR to the whitelisted addresses.
     */
    getNominalRestrictedBalance(): Promise<BN>;
    /**
     * @return {Promise<BN>} Amount of nanotoncoins that can be spent after the timelock only (whitelisted addresses not used).
     */
    getNominalLockedBalance(): Promise<BN>;
    /**
     * @return {Promise<[BN,BN,BN]>} Total amount of nanotoncoins on the contract,
     * nominal restricted value
     * nominal locked value
     */
    getBalances(): Promise<[BN, BN, BN]>;
}
import { Address } from "../../utils";
import { Cell } from "../../boc";
import { WalletContract } from "../wallet/WalletContract";
//# sourceMappingURL=index.d.ts.map