/**
 * @param cell  {Cell}
 * @param publicKey {Uint8Array}
 */
export function writePublicKey(cell: Cell, publicKey: Uint8Array): void;
/**
 * @param cell  {Cell}
 * @param signature {Uint8Array}
 */
export function writeSignature(cell: Cell, signature: Uint8Array): void;
/**
 * @param signature {Uint8Array}
 * @returns {Cell}
 */
export function createSignatureCell(signature: Uint8Array): Cell;
export const tag_init: 1768843636;
export const tag_cooperative_close: 1131179891;
export const tag_cooperative_commit: 1128492404;
export const tag_start_uncooperative_close: 1433289580;
export const tag_challenge_state: 1130915665;
export const tag_settle_conditionals: 1131168622;
export const tag_state: 1130910580;
export const op_top_up_balance: 1741148801;
export const op_init_channel: 235282626;
export const op_cooperative_close: 1433884798;
export const op_cooperative_commit: 2040604399;
export const op_start_uncooperative_close: 521476815;
export const op_challenge_quarantined_state: 143567410;
export const op_settle_conditionals: 1727459433;
export const op_finish_uncooperative_close: 625158801;
export const op_channel_closed: -572749638;
/**
 * @param params    {{coinsA: BN, coinsB: BN}}
 * @returns {Cell}
 */
export function createTopUpBalance(params: {
    coinsA: BN;
    coinsB: BN;
}): Cell;
/**
 * @param params    {{channelId: BN, balanceA: BN, balanceB: BN}}
 * @returns {Cell}
 */
export function createInitChannelBody(params: {
    channelId: BN;
    balanceA: BN;
    balanceB: BN;
}): Cell;
/**
 * @param params    {{channelId: BN, balanceA: BN, balanceB: BN, seqnoA: BN, seqnoB: BN}}
 * @returns {Cell}
 */
export function createCooperativeCloseChannelBody(params: {
    channelId: BN;
    balanceA: BN;
    balanceB: BN;
    seqnoA: BN;
    seqnoB: BN;
}): Cell;
/**
 * @param params    {{channelId: BN, seqnoA: BN, seqnoB: BN}}
 * @returns {Cell}
 */
export function createCooperativeCommitBody(params: {
    channelId: BN;
    seqnoA: BN;
    seqnoB: BN;
}): Cell;
/**
 * @param params    {{amount: BN, condition: Cell}} condition is code
 * @returns {Cell}
 */
export function createConditionalPayment(params: {
    amount: BN;
    condition: Cell;
}): Cell;
/**
 * @param params    {{seqno: BN, sentCoins: BN, conditionals: Cell | null}} conditionals - dictionary with uint32 keys and values created by `createConditionalPayment`
 * @returns {Cell}
 */
export function createSemiChannelBody(params: {
    seqno: BN;
    sentCoins: BN;
    conditionals: Cell | null;
}): Cell;
/**
 * @param params    {{channelId: BN, semiChannelBody: Cell, counterpartySemiChannelBody?: Cell}} created by `createSemiChannelBody`
 * @returns {Cell}
 */
export function createSemiChannelState(params: {
    channelId: BN;
    semiChannelBody: Cell;
    counterpartySemiChannelBody?: Cell;
}): Cell;
/**
 * @param params    {{signature: Uint8Array, state: Cell}}  `state` created by `createSemiChannelState`
 */
export function createSignedSemiChannelState(params: {
    signature: Uint8Array;
    state: Cell;
}): Cell;
/**
 * @param params    {{channelId: BN, signedSemiChannelStateA: Cell, signedSemiChannelStateB: Cell}} `signedSemiChannelState` created by `createSignedSemiChannelState`
 * @returns {Cell}
 */
export function createStartUncooperativeCloseBody(params: {
    channelId: BN;
    signedSemiChannelStateA: Cell;
    signedSemiChannelStateB: Cell;
}): Cell;
/**
 * @param params    {{channelId: BN, signedSemiChannelStateA: Cell, signedSemiChannelStateB: Cell}} `signedSemiChannelState` created by `createSignedSemiChannelState`
 * @returns {Cell}
 */
export function createChallengeQuarantinedStateBody(params: {
    channelId: BN;
    signedSemiChannelStateA: Cell;
    signedSemiChannelStateB: Cell;
}): Cell;
/**
 * @param params    {{channelId: BN, conditionalsToSettle: Cell | null}} conditionalsToSettle - dictionary with uint32 keys and values created by `createConditionalPayment`
 * @returns {Cell}
 */
export function createSettleConditionalsBody(params: {
    channelId: BN;
    conditionalsToSettle: Cell | null;
}): Cell;
/**
 * @returns {Cell}
 */
export function createFinishUncooperativeClose(): Cell;
/**
 * @param params    {{op: number, isA: boolean, signature: Uint8Array, cell: Cell}}
 * @return {Cell}
 */
export function createOneSignature(params: {
    op: number;
    isA: boolean;
    signature: Uint8Array;
    cell: Cell;
}): Cell;
/**
 * @param params    {{op: number, signatureA: Uint8Array, signatureB: Uint8Array, cell: Cell}}
 * @return {Cell}
 */
export function createTwoSignature(params: {
    op: number;
    signatureA: Uint8Array;
    signatureB: Uint8Array;
    cell: Cell;
}): Cell;
import { Cell } from "../../boc";
//# sourceMappingURL=PaymentUtils.d.ts.map