export class NftCollection extends Contract {
    /**
     * @param provider
     * @param options   {{ownerAddress: Address, collectionContentUri: string, nftItemContentBaseUri: string, nftItemCodeHex: string, royalty: number, royaltyAddress: Address, address?: Address | string, code?: Cell}}
     */
    constructor(provider: any, options: {
        ownerAddress: Address;
        collectionContentUri: string;
        nftItemContentBaseUri: string;
        nftItemCodeHex: string;
        royalty: number;
        royaltyAddress: Address;
        address?: Address | string;
        code?: Cell;
    });
    /**
     * @private
     * @param params {{collectionContentUri: string, nftItemContentBaseUri: string}}
     * @return {Cell}
     */
    private createContentCell;
    /**
     * @private
     * @param params    {{royaltyFactor: number, royaltyBase: number, royaltyAddress: Address}}
     * @return {Cell}
     */
    private createRoyaltyCell;
    /**
     * params   {{itemIndex: BN|number, amount: BN, itemOwnerAddress: Address, itemContentUri: string, queryId?: number}}
     * @return {Cell}
     */
    createMintBody(params: any): Cell;
    /**
     * params   {{queryId?: number}}
     * @return {Cell}
     */
    createGetRoyaltyParamsBody(params: any): Cell;
    /**
     * params   {{queryId?: number, newOwnerAddress: Address}}
     * @return {Cell}
     */
    createChangeOwnerBody(params: any): Cell;
    /**
     * @param params    {{collectionContentUri: string, nftItemContentBaseUri: string, royalty: number, royaltyAddress: Address, queryId?: number}}
     * @return {Cell}
     */
    createEditContentBody(params: {
        collectionContentUri: string;
        nftItemContentBaseUri: string;
        royalty: number;
        royaltyAddress: Address;
        queryId?: number;
    }): Cell;
    /**
     * @return {Promise<{nextItemIndex: number, itemsCount: BN, ownerAddress: Address, collectionContentCell: Cell, collectionContentUri: string|null}>}
     */
    getCollectionData(): Promise<{
        nextItemIndex: number;
        itemsCount: BN;
        ownerAddress: Address;
        collectionContentCell: Cell;
        collectionContentUri: string | null;
    }>;
    /**
     * @param nftItem   {NftItem}
     * @return {Promise<{isInitialized: boolean, index: number, itemIndex: BN, collectionAddress: Address, ownerAddress: Address|null, contentCell: Cell, contentUri: string|null}>}
     */
    getNftItemContent(nftItem: NftItem): Promise<{
        isInitialized: boolean;
        index: number;
        itemIndex: BN;
        collectionAddress: Address;
        ownerAddress: Address | null;
        contentCell: Cell;
        contentUri: string | null;
    }>;
    /**
     * @param index {BN|number}
     * @return {Promise<Address>}
     */
    getNftItemAddressByIndex(index: BN | number): Promise<Address>;
    /**
     * @return {Promise<{royalty: number, royaltyFactor: number, royaltyBase: number, royaltyAddress: Address}>}
     */
    getRoyaltyParams(): Promise<{
        royalty: number;
        royaltyFactor: number;
        royaltyBase: number;
        royaltyAddress: Address;
    }>;
}
import { Contract } from "../../index.js";
import { Cell } from "../../../boc";
import { Address } from "../../../utils";
//# sourceMappingURL=NftCollection.d.ts.map