/**
 * Abstract standard wallet class
 */
export class WalletContract extends Contract {
    /**
     * @param provider    {HttpProvider}
     * @param options?    {{code: Cell, publicKey?: Uint8Array, address?: Address | string, wc?: number}}
     */
    constructor(provider: HttpProvider, options: any);
    methods: {
        /**
         * @param   params {{secretKey: Uint8Array, toAddress: Address | string, amount: BN | number, seqno: number, payload: string | Uint8Array | Cell, sendMode: number, stateInit?: Cell, expireAt?: number}}
         */
        transfer: (params: {
            secretKey: Uint8Array;
            toAddress: Address | string;
            amount: BN | number;
            seqno: number;
            payload: string | Uint8Array | Cell;
            sendMode: number;
            stateInit?: Cell;
            expireAt?: number;
        }) => {
            getQuery: () => Promise<any>;
            send: () => Promise<any>;
            estimateFee: () => Promise<any>;
        };
        /**
         * @param   params {{secretKey: Uint8Array, seqno: number, expireAt?: number, messages: [{address: Address | string, amount: BN, payload?: string | Uint8Array | Cell, sendMode?: number, stateInit?: Cell }]}}
         */
        transfers: (params: {
            secretKey: Uint8Array;
            seqno: number;
            expireAt?: number;
            messages: [{
                address: Address | string;
                amount: BN;
                payload?: string | Uint8Array | Cell;
                sendMode?: number;
                stateInit?: Cell;
            }];
        }) => {
            getQuery: () => Promise<any>;
            send: () => Promise<any>;
            estimateFee: () => Promise<any>;
        };
        seqno: () => {
            /**
             * @return {Promise<number|null>}
             */
            call: () => Promise<number | null>;
        };
    };
    /**
     * @param secretKey {Uint8Array}
     */
    deploy: (secretKey: Uint8Array) => {
        getQuery: () => Promise<any>;
        send: () => Promise<any>;
        estimateFee: () => Promise<any>;
    };
    getName(): void;
    /**
     * @protected
     * @param   seqno?   {number}
     * @return {Cell}
     */
    protected createSigningMessage(seqno: any): Cell;
    /**
     * External message for initialization
     * @param secretKey  {Uint8Array} nacl.KeyPair.secretKey
     * @return {{address: Address, message: Cell, body: Cell, sateInit: Cell, code: Cell, data: Cell}}
     */
    createInitExternalMessage(secretKey: Uint8Array): {
        address: Address;
        message: Cell;
        body: Cell;
        sateInit: Cell;
        code: Cell;
        data: Cell;
    };
    /**
     * @protected
     * @param signingMessage {Cell}
     * @param secretKey {Uint8Array}  nacl.KeyPair.secretKey
     * @param seqno {number}
     * @param dummySignature?    {boolean}
     * @return {Promise<{address: Address, signature: Uint8Array, message: Cell, cell: Cell, body: Cell, resultMessage: Cell}>}
     */
    protected createExternalMessage(signingMessage: Cell, secretKey: Uint8Array, seqno: number, dummySignature?: boolean): Promise<{
        address: Address;
        signature: Uint8Array;
        message: Cell;
        cell: Cell;
        body: Cell;
        resultMessage: Cell;
    }>;
    /**
     * @param secretKey {Uint8Array}  nacl.KeyPair.secretKey
     * @param address   {Address | string}
     * @param amount    {BN | number} in nanotons
     * @param seqno {number}
     * @param payload?   {string | Uint8Array | Cell}
     * @param sendMode?  {number}
     * @param dummySignature?    {boolean}
     * @param stateInit? {Cell}
     * @param expireAt? {number}
     * @return {Promise<{address: Address, signature: Uint8Array, message: Cell, cell: Cell, body: Cell, resultMessage: Cell}>}
     */
    createTransferMessage(secretKey: Uint8Array, address: Address | string, amount: BN | number, seqno: number, payload?: string, sendMode?: number, dummySignature?: boolean, stateInit?: any, expireAt?: any): Promise<{
        address: Address;
        signature: Uint8Array;
        message: Cell;
        cell: Cell;
        body: Cell;
        resultMessage: Cell;
    }>;
    /**
     * @param secretKey {Uint8Array}  nacl.KeyPair.secretKey
     * @param seqno {number}
     * @param messages {[{toAddress: Address | string, amount: BN, payload?: string | Uint8Array | Cell, sendMode?: number, stateInit?: Cell }]} up to 4 messages
     * @param dummySignature?    {boolean}
     * @param expireAt? {number}
     * @return {Promise<{address: Address, signature: Uint8Array, message: Cell, cell: Cell, body: Cell, resultMessage: Cell}>}
     */
    createTransferMessages(secretKey: Uint8Array, seqno: number, messages: [{
        toAddress: Address | string;
        amount: BN;
        payload?: string | Uint8Array | Cell;
        sendMode?: number;
        stateInit?: Cell;
    }], dummySignature?: boolean, expireAt?: any): Promise<{
        address: Address;
        signature: Uint8Array;
        message: Cell;
        cell: Cell;
        body: Cell;
        resultMessage: Cell;
    }>;
}
import { Contract } from "../index.js";
import { Address } from "../../utils";
import { Cell } from "../../boc";
//# sourceMappingURL=WalletContract.d.ts.map