export class WalletV4ContractR2 extends WalletContract {
    getName(): string;
    /**
     * @override
     * @private
     * @param   seqno?   {number}
     * @param   expireAt? {number}
     * @param   withoutOp? {boolean}
     * @return {Cell}
     */
    private override createSigningMessage;
    /**
     * @param   params {{secretKey: Uint8Array, seqno: number, pluginWc: number, amount: BN, stateInit: Cell, body: Cell, expireAt?: number}}
     */
    deployAndInstallPlugin(params: {
        secretKey: Uint8Array;
        seqno: number;
        pluginWc: number;
        amount: BN;
        stateInit: Cell;
        body: Cell;
        expireAt?: number;
    }): Promise<{
        address: Address;
        signature: Uint8Array;
        message: Cell;
        cell: Cell;
        body: Cell;
        resultMessage: Cell;
    }>;
    /**
     * @private
     * @param   params {{secretKey: Uint8Array, seqno: number, pluginAddress: string | Address, amount?: BN, queryId?: number, expireAt?: number}}
     * @param   isInstall {boolean} install or uninstall
     */
    private _setPlugin;
    /**
     * @param   params {{secretKey: Uint8Array, seqno: number, pluginAddress: string | Address, amount?: BN, queryId?: number, expireAt?: number}}
     */
    installPlugin(params: {
        secretKey: Uint8Array;
        seqno: number;
        pluginAddress: string | Address;
        amount?: BN;
        queryId?: number;
        expireAt?: number;
    }): Promise<{
        address: Address;
        signature: Uint8Array;
        message: Cell;
        cell: Cell;
        body: Cell;
        resultMessage: Cell;
    }>;
    /**
     * @param   params {{secretKey: Uint8Array, seqno: number, pluginAddress: string | Address, amount?: BN, queryId?: number, expireAt?: number}}
     */
    removePlugin(params: {
        secretKey: Uint8Array;
        seqno: number;
        pluginAddress: string | Address;
        amount?: BN;
        queryId?: number;
        expireAt?: number;
    }): Promise<{
        address: Address;
        signature: Uint8Array;
        message: Cell;
        cell: Cell;
        body: Cell;
        resultMessage: Cell;
    }>;
    /**
     * @return {Promise<number>}
     */
    getWalletId(): Promise<number>;
    /**
     * @return {Promise<BN>}
     */
    getPublicKey(): Promise<BN>;
    /**
     * @param pluginAddress {string | Address}
     * @return {Promise<boolean>}
     */
    isPluginInstalled(pluginAddress: string | Address): Promise<boolean>;
    /**
     * @return {Promise<string[]>} plugins addresses
     */
    getPluginsList(): Promise<string[]>;
}
export namespace WalletV4ContractR2 {
    export { parseWalletV3TransferQuery as parseTransferQuery };
    export { parseWalletV3TransferBody as parseTransferBody };
}
import { WalletContract } from "./WalletContract";
import { Cell } from "../../boc";
import { Address } from "../../utils";
import { parseWalletV3TransferQuery } from "./WalletQueryParser";
import { parseWalletV3TransferBody } from "./WalletQueryParser";
//# sourceMappingURL=WalletContractV4R2.d.ts.map