export = TonWeb;
declare class TonWeb {
    constructor(provider: any);
    version: string;
    utils: typeof utils;
    Address: typeof utils.Address;
    boc: typeof boc;
    Contract: typeof Contract;
    BlockSubscription: typeof BlockSubscription;
    InMemoryBlockStorage: typeof InMemoryBlockStorage;
    provider: any;
    dns: import("./contract/dns/Dns").default;
    wallet: Wallets;
    payments: Payments;
    lockupWallet: {
        LockupWalletV1: {
            new (provider: HttpProvider, options: {
                publicKey?: Uint8Array;
                address?: string | utils.Address;
                wc?: number;
                config: any;
            }): {
                /**
                 * Invoke get-method of smart contract
                 * @param address   {Address | string}    contract address
                 * @param method   {string | number}        method name or method id
                 * @param params?   Array of stack elements: [['num',3], ['cell', cell_object], ['slice', slice_object]]
                 */
                getName(): string;
                createSigningMessage(seqno: any, withoutOp: any): boc.Cell;
                createDataCell(): boc.Cell;
                getWalletId(): Promise<number>;
                getPublicKey(): Promise<BN>;
                getLiquidBalance(): Promise<BN>;
                getNominalRestrictedBalance(): Promise<BN>;
                getNominalLockedBalance(): Promise<BN>;
                getBalances(): Promise<[BN, BN, BN]>;
                methods: {
                    transfer: (params: {
                        secretKey: Uint8Array;
                        toAddress: string | utils.Address;
                        amount: any;
                        seqno: number;
                        payload: string | Uint8Array | boc.Cell;
                        sendMode: number;
                        stateInit?: boc.Cell;
                        expireAt?: number;
                    }) => {
                        getQuery: () => Promise<any>;
                        send: () => Promise<any>;
                        estimateFee: () => Promise<any>;
                    };
                    transfers: (params: {
                        secretKey: Uint8Array;
                        seqno: number;
                        expireAt?: number;
                        messages: [{
                            address: string | utils.Address;
                            amount: BN;
                            payload?: string | Uint8Array | boc.Cell;
                            sendMode?: number;
                            stateInit?: boc.Cell;
                        }];
                    }) => {
                        getQuery: () => Promise<any>;
                        send: () => Promise<any>;
                        estimateFee: () => Promise<any>;
                    };
                    seqno: () => {
                        call: () => Promise<number>;
                    };
                };
                deploy: (secretKey: Uint8Array) => {
                    getQuery: () => Promise<any>;
                    send: () => Promise<any>;
                    estimateFee: () => Promise<any>;
                };
                createInitExternalMessage(secretKey: Uint8Array): {
                    address: utils.Address;
                    message: boc.Cell;
                    body: boc.Cell;
                    sateInit: boc.Cell;
                    code: boc.Cell;
                    data: boc.Cell;
                };
                createExternalMessage(signingMessage: boc.Cell, secretKey: Uint8Array, seqno: number, dummySignature?: boolean): Promise<{
                    address: utils.Address;
                    signature: Uint8Array;
                    message: boc.Cell;
                    cell: boc.Cell;
                    body: boc.Cell;
                    resultMessage: boc.Cell;
                }>;
                createTransferMessage(secretKey: Uint8Array, address: string | utils.Address, amount: any, seqno: number, payload?: string, sendMode?: number, dummySignature?: boolean, stateInit?: any, expireAt?: any): Promise<{
                    address: utils.Address;
                    signature: Uint8Array;
                    message: boc.Cell;
                    cell: boc.Cell;
                    body: boc.Cell;
                    resultMessage: boc.Cell;
                }>;
                createTransferMessages(secretKey: Uint8Array, seqno: number, messages: [{
                    toAddress: string | utils.Address;
                    amount: BN;
                    payload?: string | Uint8Array | boc.Cell;
                    sendMode?: number;
                    stateInit?: boc.Cell;
                }], dummySignature?: boolean, expireAt?: any): Promise<{
                    address: utils.Address;
                    signature: Uint8Array;
                    message: boc.Cell;
                    cell: boc.Cell;
                    body: boc.Cell;
                    resultMessage: boc.Cell;
                }>;
                provider: HttpProvider;
                options: {
                    code?: boc.Cell;
                    address?: string | utils.Address;
                    wc?: number;
                };
                address: utils.Address;
                getAddress(): Promise<utils.Address>;
                createCodeCell(): boc.Cell;
                createStateInit(): Promise<{
                    stateInit: boc.Cell;
                    address: utils.Address;
                    code: boc.Cell;
                    data: boc.Cell;
                }>;
            };
            createStateInit(code: boc.Cell, data: boc.Cell, library?: null, splitDepth?: null, ticktock?: null): boc.Cell;
            createInternalMessageHeader(dest: string | utils.Address, gramValue?: any, ihrDisabled?: boolean, bounce?: boolean, bounced?: boolean, src?: string | utils.Address, currencyCollection?: null, ihrFees?: any, fwdFees?: any, createdLt?: any, createdAt?: any): boc.Cell;
            createExternalMessageHeader(dest: string | utils.Address, src?: string | utils.Address, importFee?: any): boc.Cell;
            createOutMsg(address: string | utils.Address, amount: BN, payload: string | Uint8Array | boc.Cell, stateInit?: any): boc.Cell;
            createCommonMsgInfo(header: boc.Cell, stateInit?: any, body?: any): boc.Cell;
            createMethod(provider: any, queryPromise: any): {
                getQuery: () => Promise<any>;
                send: () => Promise<any>;
                estimateFee: () => Promise<any>;
            };
        };
        all: {
            'lockup-0.1': {
                new (provider: HttpProvider, options: {
                    publicKey?: Uint8Array;
                    address?: string | utils.Address;
                    wc?: number;
                    config: any;
                }): {
                    /**
                     * Invoke get-method of smart contract
                     * @param address   {Address | string}    contract address
                     * @param method   {string | number}        method name or method id
                     * @param params?   Array of stack elements: [['num',3], ['cell', cell_object], ['slice', slice_object]]
                     */
                    getName(): string;
                    createSigningMessage(seqno: any, withoutOp: any): boc.Cell;
                    createDataCell(): boc.Cell;
                    getWalletId(): Promise<number>;
                    getPublicKey(): Promise<BN>;
                    getLiquidBalance(): Promise<BN>;
                    getNominalRestrictedBalance(): Promise<BN>;
                    getNominalLockedBalance(): Promise<BN>;
                    getBalances(): Promise<[BN, BN, BN]>;
                    methods: {
                        transfer: (params: {
                            secretKey: Uint8Array;
                            toAddress: string | utils.Address;
                            amount: any;
                            seqno: number;
                            payload: string | Uint8Array | boc.Cell;
                            sendMode: number;
                            stateInit?: boc.Cell;
                            expireAt?: number;
                        }) => {
                            getQuery: () => Promise<any>;
                            send: () => Promise<any>;
                            estimateFee: () => Promise<any>;
                        };
                        transfers: (params: {
                            secretKey: Uint8Array;
                            seqno: number;
                            expireAt?: number;
                            messages: [{
                                address: string | utils.Address;
                                amount: BN;
                                payload?: string | Uint8Array | boc.Cell;
                                sendMode?: number;
                                stateInit?: boc.Cell;
                            }];
                        }) => {
                            getQuery: () => Promise<any>;
                            send: () => Promise<any>;
                            estimateFee: () => Promise<any>;
                        };
                        seqno: () => {
                            call: () => Promise<number>;
                        };
                    };
                    deploy: (secretKey: Uint8Array) => {
                        getQuery: () => Promise<any>;
                        send: () => Promise<any>;
                        estimateFee: () => Promise<any>;
                    };
                    createInitExternalMessage(secretKey: Uint8Array): {
                        address: utils.Address;
                        message: boc.Cell;
                        body: boc.Cell;
                        sateInit: boc.Cell;
                        code: boc.Cell;
                        data: boc.Cell;
                    };
                    createExternalMessage(signingMessage: boc.Cell, secretKey: Uint8Array, seqno: number, dummySignature?: boolean): Promise<{
                        address: utils.Address;
                        signature: Uint8Array;
                        message: boc.Cell;
                        cell: boc.Cell;
                        body: boc.Cell;
                        resultMessage: boc.Cell;
                    }>;
                    createTransferMessage(secretKey: Uint8Array, address: string | utils.Address, amount: any, seqno: number, payload?: string, sendMode?: number, dummySignature?: boolean, stateInit?: any, expireAt?: any): Promise<{
                        address: utils.Address;
                        signature: Uint8Array;
                        message: boc.Cell;
                        cell: boc.Cell;
                        body: boc.Cell;
                        resultMessage: boc.Cell;
                    }>;
                    createTransferMessages(secretKey: Uint8Array, seqno: number, messages: [{
                        toAddress: string | utils.Address;
                        amount: BN;
                        payload?: string | Uint8Array | boc.Cell;
                        sendMode?: number;
                        stateInit?: boc.Cell;
                    }], dummySignature?: boolean, expireAt?: any): Promise<{
                        address: utils.Address;
                        signature: Uint8Array;
                        message: boc.Cell;
                        cell: boc.Cell;
                        body: boc.Cell;
                        resultMessage: boc.Cell;
                    }>;
                    provider: HttpProvider;
                    options: {
                        code?: boc.Cell;
                        address?: string | utils.Address;
                        wc?: number;
                    };
                    address: utils.Address;
                    getAddress(): Promise<utils.Address>;
                    createCodeCell(): boc.Cell;
                    createStateInit(): Promise<{
                        stateInit: boc.Cell;
                        address: utils.Address;
                        code: boc.Cell;
                        data: boc.Cell;
                    }>;
                };
                createStateInit(code: boc.Cell, data: boc.Cell, library?: null, splitDepth?: null, ticktock?: null): boc.Cell;
                createInternalMessageHeader(dest: string | utils.Address, gramValue?: any, ihrDisabled?: boolean, bounce?: boolean, bounced?: boolean, src?: string | utils.Address, currencyCollection?: null, ihrFees?: any, fwdFees?: any, createdLt?: any, createdAt?: any): boc.Cell;
                createExternalMessageHeader(dest: string | utils.Address, src?: string | utils.Address, importFee?: any): boc.Cell;
                createOutMsg(address: string | utils.Address, amount: BN, payload: string | Uint8Array | boc.Cell, stateInit?: any): boc.Cell;
                createCommonMsgInfo(header: boc.Cell, stateInit?: any, body?: any): boc.Cell;
                createMethod(provider: any, queryPromise: any): {
                    getQuery: () => Promise<any>;
                    send: () => Promise<any>;
                    estimateFee: () => Promise<any>;
                };
            };
        };
        list: {
            new (provider: HttpProvider, options: {
                publicKey?: Uint8Array;
                address?: string | utils.Address;
                wc?: number;
                config: any;
            }): {
                /**
                 * Invoke get-method of smart contract
                 * @param address   {Address | string}    contract address
                 * @param method   {string | number}        method name or method id
                 * @param params?   Array of stack elements: [['num',3], ['cell', cell_object], ['slice', slice_object]]
                 */
                getName(): string;
                createSigningMessage(seqno: any, withoutOp: any): boc.Cell;
                createDataCell(): boc.Cell;
                getWalletId(): Promise<number>;
                getPublicKey(): Promise<BN>;
                getLiquidBalance(): Promise<BN>;
                getNominalRestrictedBalance(): Promise<BN>;
                getNominalLockedBalance(): Promise<BN>;
                getBalances(): Promise<[BN, BN, BN]>;
                methods: {
                    transfer: (params: {
                        secretKey: Uint8Array;
                        toAddress: string | utils.Address;
                        amount: any;
                        seqno: number;
                        payload: string | Uint8Array | boc.Cell;
                        sendMode: number;
                        stateInit?: boc.Cell;
                        expireAt?: number;
                    }) => {
                        getQuery: () => Promise<any>;
                        send: () => Promise<any>;
                        estimateFee: () => Promise<any>;
                    };
                    transfers: (params: {
                        secretKey: Uint8Array;
                        seqno: number;
                        expireAt?: number;
                        messages: [{
                            address: string | utils.Address;
                            amount: BN;
                            payload?: string | Uint8Array | boc.Cell;
                            sendMode?: number;
                            stateInit?: boc.Cell;
                        }];
                    }) => {
                        getQuery: () => Promise<any>;
                        send: () => Promise<any>;
                        estimateFee: () => Promise<any>;
                    };
                    seqno: () => {
                        call: () => Promise<number>;
                    };
                };
                deploy: (secretKey: Uint8Array) => {
                    getQuery: () => Promise<any>;
                    send: () => Promise<any>;
                    estimateFee: () => Promise<any>;
                };
                createInitExternalMessage(secretKey: Uint8Array): {
                    address: utils.Address;
                    message: boc.Cell;
                    body: boc.Cell;
                    sateInit: boc.Cell;
                    code: boc.Cell;
                    data: boc.Cell;
                };
                createExternalMessage(signingMessage: boc.Cell, secretKey: Uint8Array, seqno: number, dummySignature?: boolean): Promise<{
                    address: utils.Address;
                    signature: Uint8Array;
                    message: boc.Cell;
                    cell: boc.Cell;
                    body: boc.Cell;
                    resultMessage: boc.Cell;
                }>;
                createTransferMessage(secretKey: Uint8Array, address: string | utils.Address, amount: any, seqno: number, payload?: string, sendMode?: number, dummySignature?: boolean, stateInit?: any, expireAt?: any): Promise<{
                    address: utils.Address;
                    signature: Uint8Array;
                    message: boc.Cell;
                    cell: boc.Cell;
                    body: boc.Cell;
                    resultMessage: boc.Cell;
                }>;
                createTransferMessages(secretKey: Uint8Array, seqno: number, messages: [{
                    toAddress: string | utils.Address;
                    amount: BN;
                    payload?: string | Uint8Array | boc.Cell;
                    sendMode?: number;
                    stateInit?: boc.Cell;
                }], dummySignature?: boolean, expireAt?: any): Promise<{
                    address: utils.Address;
                    signature: Uint8Array;
                    message: boc.Cell;
                    cell: boc.Cell;
                    body: boc.Cell;
                    resultMessage: boc.Cell;
                }>;
                provider: HttpProvider;
                options: {
                    code?: boc.Cell;
                    address?: string | utils.Address;
                    wc?: number;
                };
                address: utils.Address;
                getAddress(): Promise<utils.Address>;
                createCodeCell(): boc.Cell;
                createStateInit(): Promise<{
                    stateInit: boc.Cell;
                    address: utils.Address;
                    code: boc.Cell;
                    data: boc.Cell;
                }>;
            };
            createStateInit(code: boc.Cell, data: boc.Cell, library?: null, splitDepth?: null, ticktock?: null): boc.Cell;
            createInternalMessageHeader(dest: string | utils.Address, gramValue?: any, ihrDisabled?: boolean, bounce?: boolean, bounced?: boolean, src?: string | utils.Address, currencyCollection?: null, ihrFees?: any, fwdFees?: any, createdLt?: any, createdAt?: any): boc.Cell;
            createExternalMessageHeader(dest: string | utils.Address, src?: string | utils.Address, importFee?: any): boc.Cell;
            createOutMsg(address: string | utils.Address, amount: BN, payload: string | Uint8Array | boc.Cell, stateInit?: any): boc.Cell;
            createCommonMsgInfo(header: boc.Cell, stateInit?: any, body?: any): boc.Cell;
            createMethod(provider: any, queryPromise: any): {
                getQuery: () => Promise<any>;
                send: () => Promise<any>;
                estimateFee: () => Promise<any>;
            };
        }[];
    };
    /**
     * Use this method to get transaction history of a given address.
     * @param address   {Address | string}
     * @param limit?    {number}
     * @param lt?    {number}
     * @param txhash?    {string}   in HEX
     * @param to_lt?    {number}
     * @return array of transaction objects
     */
    getTransactions(address: typeof utils.Address | string, limit?: number, lt?: any, txhash?: any, to_lt?: any): Promise<any>;
    /**
     * @param address   {Address | string}
     * @return {Promise<string>} - The current balance for the given address in nanograms.
     */
    getBalance(address: typeof utils.Address | string): Promise<string>;
    /**
     * Use this method to send serialized boc file: fully packed and serialized external message.
     * @param bytes {Uint8Array}
     */
    sendBoc(bytes: Uint8Array): Promise<any>;
    /**
     * Invoke get-method of smart contract
     * @param address   {Address | string}    contract address
     * @param method   {string | number}        method name or method id
     * @param params?   Array of stack elements: [['num',3], ['cell', cell_object], ['slice', slice_object]]
     */
    call(address: typeof utils.Address | string, method: string | number, params?: any[]): Promise<any>;
}
declare namespace TonWeb {
    export { version };
    export { utils };
    export { Address };
    export { boc };
    export { HttpProvider };
    export { Contract };
    export { Wallets };
    export { LockupWallets };
    export { SubscriptionContract };
    export { BlockSubscription };
    export { InMemoryBlockStorage };
    export namespace ledger {
        export { TransportWebUSB };
        export { TransportWebHID };
        export { BluetoothTransport };
        export { AppTon };
    }
    export namespace token {
        export { NFT as nft };
        export { JETTON as ft };
        export { JETTON as jetton };
    }
    export { Dns as dns };
    export { Payments as payments };
}
import utils = require("./utils");
import boc = require("./boc");
import { Contract } from "./contract";
import { BlockSubscription } from "./providers/blockSubscription";
import { InMemoryBlockStorage } from "./providers/blockSubscription";
import Wallets_1 = require("./contract/wallet");
import Wallets = Wallets_1.default;
import { Payments } from "./contract/payments/index";
declare const version: "0.0.60";
declare const Address: typeof utils.Address;
import HttpProvider_1 = require("./providers");
import HttpProvider = HttpProvider_1.default;
import LockupWallets_1 = require("./contract/lockup");
import LockupWallets = LockupWallets_1.default;
import { SubscriptionContract } from "./contract/subscription/index";
import AppTon = require("./ledger/AppTon");
import NFT_1 = require("./contract/token/nft");
import NFT = NFT_1.default;
import JETTON_1 = require("./contract/token/ft");
import JETTON = JETTON_1.default;
import { Dns_1 } from "./contract/dns";
//# sourceMappingURL=index.d.ts.map