export = AppTon;
declare class AppTon {
    /**
     * @param transport {Transport} @ledgerhq/hw-transport
     * @param ton   {TonWeb}
     */
    constructor(transport: Transport, ton: TonWeb);
    transport: Transport;
    ton: TonWeb;
    ADDRESS_FORMAT_HEX: number;
    ADDRESS_FORMAT_USER_FRIENDLY: number;
    ADDRESS_FORMAT_URL_SAFE: number;
    ADDRESS_FORMAT_BOUNCEABLE: number;
    ADDRESS_FORMAT_TEST_ONLY: number;
    /***
     * Get App version
     * @return {{version: string}}
     */
    getAppConfiguration(): {
        version: string;
    };
    /**
     * This command returns a public key for the given account number
     * @param accountNumber {number}
     * @param isDisplay {boolean} display public key and confirm before returning
     * @return {{publicKey: Uint8Array}}
     */
    getPublicKey(accountNumber: number, isDisplay: boolean): {
        publicKey: Uint8Array;
    };
    /**
     * This command returns a wallet v3R1 address for the given account number
     * @param accountNumber {number}
     * @param isDisplay {boolean} display address and confirm before returning
     * @param addressFormat {number} display address format (use sum of ADDRESS_FORMAT_ constants)
     * @return {{address: Address}}
     */
    getAddress(accountNumber: number, isDisplay: boolean, addressFormat: number): {
        address: Address;
    };
    /**
     * Sign a bytes
     * @param accountNumber {number}
     * @param buffer    {Buffer}
     * @return {{signature: Buffer}}
     */
    sign(accountNumber: number, buffer: Buffer): {
        signature: Buffer;
    };
    /**
     * Sign a transfer coins message (same with TonWeb.WalletContract.createTransferMessage)
     * if seqno === 0 it will be deploy wallet + transfer coins message
     * @param accountNumber {number}
     * @param wallet {WalletContract}  Sender wallet
     * @param toAddress {String | Address}  Destination address in any format
     * @param amount    {BN | number}  Transfer value in nanograms
     * @param seqno {number}
     * @param addressFormat {number} display address format (use sum of ADDRESS_FORMAT_ constants)
     * @return
     */
    transfer(accountNumber: number, wallet: WalletContract, toAddress: string | Address, amount: BN | number, seqno: number, addressFormat: number): Promise<{
        getQuery: () => Promise<any>;
        send: () => Promise<any>;
        estimateFee: () => Promise<any>;
    }>;
}
import { Address } from "../utils";
//# sourceMappingURL=AppTon.d.ts.map