/**
 * Storage for storing block numbers that we have already processed.
 * Used by `BlockSubscription`.
 *
 * Dumb in-memory implementation.
 */
export class InMemoryBlockStorage {
    /**
     * @param logFunction?   {(text: string) => void}
     */
    constructor(logFunction: any);
    masterchainBlocks: {};
    shardchainBlocks: {};
    logFunction: any;
    /**
     * @private
     * Insert new UNprocessed shardchain block numbers
     * Block number (workchain + shardId + shardBlockNumber) should be IGNORED if it is already in the storage
     * @param   shardBlockNumbers {[{workchain: number, shardId: string, shardBlockNumber: number}]}
     */
    private insertShardBlocks;
    /**
     * Insert new processed masterchain block number & new UNprocessed shardchains blocks numbers
     * Must be in single DB transaction
     * @param   mcBlockNumber {number}
     * @param   shardBlockNumbers {[{workchain: number, shardId: string, shardBlockNumber: number}]}
     */
    insertBlocks(mcBlockNumber: number, shardBlockNumbers: [{
        workchain: number;
        shardId: string;
        shardBlockNumber: number;
    }]): Promise<void>;
    /**
     * Get last processed masterchain block number
     * @return {Promise<number | undefined>}
     */
    getLastMasterchainBlockNumber(): Promise<number | undefined>;
    /**
     * Set that this shardchain block number processed & insert new UNprocessed shardchains blocks numbers
     * Must be in single DB transaction
     * @param   workchain {number}
     * @param   shardId {string}
     * @param   shardBlockNumber    {number}
     * @param   prevShardBlocks    {[{workchain: number, shardId: string, shardBlockNumber: number}]}
     */
    setBlockProcessed(workchain: number, shardId: string, shardBlockNumber: number, prevShardBlocks: [{
        workchain: number;
        shardId: string;
        shardBlockNumber: number;
    }]): Promise<void>;
    /**
     * Get any unprocesed shard block number (order is not important)
     * @return {Promise<{workchain: number, shardId: string, shardBlockNumber: number}>}
     */
    getUnprocessedShardBlock(): Promise<{
        workchain: number;
        shardId: string;
        shardBlockNumber: number;
    }>;
}
//# sourceMappingURL=InMemoryBlockStorage.d.ts.map