import nacl = require("tweetnacl");
/**
 * @param bytes {Uint8Array}
 * @return  {Promise<ArrayBuffer>}
 */
export function sha256(bytes: Uint8Array): Promise<ArrayBuffer>;
/**
 * from nanocoins to coins
 * @param amount  {BN | string}
 * @return {string}
 */
export function fromNano(amount: BN | string): string;
/**
 * from coins to nanocoins
 * @param amount {BN | string}
 * @return {BN}
 */
export function toNano(amount: BN | string): BN;
/**
 * @param buffer  {Uint8Array}
 * @return {string}
 */
export function bytesToHex(buffer: Uint8Array): string;
/**
 * @param s {string}
 * @return {Uint8Array}
 */
export function hexToBytes(s: string): Uint8Array;
/**
 * @param str {string}
 * @param size  {number}
 * @return {Uint8Array}
 */
export function stringToBytes(str: string, size?: number): Uint8Array;
/**
 * @param bytes {Uint8Array}
 * @return {Uint8Array}
 */
export function crc32c(bytes: Uint8Array): Uint8Array;
/**
 * @param data  {ArrayLike<number>}
 * @return {Uint8Array}
 */
export function crc16(data: ArrayLike<number>): Uint8Array;
/**
 * @param a {Uint8Array}
 * @param b {Uint8Array}
 * @return {Uint8Array}
 */
export function concatBytes(a: Uint8Array, b: Uint8Array): Uint8Array;
/**
 * @param bytes {Uint8Array}
 * @return {string}
 */
export function bytesToBase64(bytes: Uint8Array): string;
/**
 * @param base64  {string}
 * @return {Uint8Array}
 */
export function base64ToBytes(base64: string): Uint8Array;
export function base64toString(base64: any): string;
export function stringToBase64(s: any): string;
/**
 * @param a {Uint8Array}
 * @param b {Uint8Array}
 * @return {boolean}
 */
export function compareBytes(a: Uint8Array, b: Uint8Array): boolean;
/**
 * @param n  {number}
 * @param ui8array  {Uint8Array}
 * @return {number}
 */
export function readNBytesUIntFromArray(n: number, ui8array: Uint8Array): number;
/**
 * @param seed  {Uint8Array}
 * @returns {nacl.SignKeyPair}
 */
export function keyPairFromSeed(seed: Uint8Array): nacl.SignKeyPair;
/**
 * @returns {nacl.SignKeyPair}
 */
export function newKeyPair(): nacl.SignKeyPair;
/**
 * @returns {Uint8Array}
 */
export function newSeed(): Uint8Array;
export { BN, nacl };
//# sourceMappingURL=Utils.d.ts.map